<!--排查单位查询-筛选弹层-->
<template>
  <van-popup
    v-model="isShowPopup"
    round
    closeable
    position="top"
    :style="{ height: '54.5%' }"
  >
    <div class="query-search-popup">
      <div class="title">安全排查查询</div>
      <van-form label-width="80px">
        <!--    整改状态选择    -->
        <template>
          <van-field
            readonly
            clickable
            name="picker"
            :value="customQueryPrams.status"
            label="整改状态"
            placeholder="点击选择整改状态"
            @click="statusPicker = true"
          />
          <van-popup v-model="statusPicker" position="bottom" get-container="body">
            <van-picker
              show-toolbar
              :columns="statusOpt"
              @confirm="({text}) => {
                this.customQueryPrams.status = text;
                this.statusPicker = false ;
             }"
              @cancel="statusPicker = false"
            />
          </van-popup>
        </template>

        <!--    排查方案选择    -->
        <template>
          <van-field
            readonly
            clickable
            name="picker"
            :value="customQueryPrams.checkschemeId"
            label="排查方案"
            placeholder="点击选择排查方案"
            @click="troubleshootingPlanPicker = true"
          />

          <van-popup v-model="troubleshootingPlanPicker" position="bottom" get-container="body">
            <van-picker
              show-toolbar
              :columns="troubleshootingPlanOpt"
              @confirm="({text}) => {
                this.customQueryPrams.checkschemeId = text;
                this.troubleshootingPlanPicker = false ;
              }"
              @cancel="troubleshootingPlanPicker = false"
            />
          </van-popup>
        </template>

        <!--受检单位类型选择显示-->
        <template>
          <van-field
            readonly
            clickable
            name="picker"
            :value="customQueryPrams.unit_type_"
            label="受检单位类型"
            placeholder="点击选择受检单位类型"
            @click="unitTypePicker = true"
          />
          <van-popup v-model="unitTypePicker" position="bottom" get-container="body">
            <van-picker
              show-toolbar
              :columns="unitsTypeOpt"
              @confirm="({text}) => {
                this.customQueryPrams.unit_type_ = text;
                this.unitTypePicker = false ;
              }"
              @cancel="unitTypePicker = false"
            />
          </van-popup>
        </template>

        <van-field
          v-model="customQueryPrams.unit_name_"
          name="受检单位名称"
          label="受检单位名称"
          placeholder="请输入受检单位名称"
        />

        <template>
          <van-field
            readonly
            clickable
            name="calendar"
            :value="customQueryPrams.checkDate"
            label="最后复查时间"
            placeholder="点击选择最后复查时间区间"
            @click="checkDatePicker = true"
          />
          <van-calendar
            color="#4187f2"
            title="最后复查时间"
            v-model="checkDatePicker"
            :min-date="new Date('1990/01/01')"
            @confirm="valArr => {
              customQueryPrams.checkDate = valArr.map(time=>moment(time).format('YYYY-MM-DD')).join(' ~ ')
              checkDatePicker = false
            }"
            type="range"
          />
        </template>

        <div class="search-btn">
          <van-button class="btn-left" block type="info" native-type="button" @click="searchData">查询</van-button>
          <van-button class="btn-right" block plain type="info" native-type="button" @click="resetData">重置
          </van-button>
        </div>
      </van-form>
    </div>
  </van-popup>
</template>

<script>
import moment from 'moment'

export default {
  name: 'QuerySearchPopup', // 排查单位查询-筛选弹层
  props: {
    // 是否展示弹层
    querySearchPopup: {
      default: false,
      type: Boolean
    },
    // 查询对象
    customQueryPrams: {
      default() {
        return {}
      },
      type: Object
    },
    // 排查方案配置数组对象
    troubleshootingPlanOpt: {
      default() {
        return []
      },
      type: Array
    },
    // 受检单位配置数组对象
    unitsTypeOpt: {
      default() {
        return []
      },
      type: Array
    },
    // 整改状态配置数组对象
    statusOpt: {
      default() {
        return []
      },
      type: Array
    }
  },
  data() {
    return {
      troubleshootingPlanPicker: false, // 排查方案显示
      statusPicker: false, // 整改状态选择显示
      unitTypePicker: false, // 受检单位类型选择显示
      checkDatePicker: false
    }
  },
  computed: {
    isShowPopup: {
      get() {
        return this.querySearchPopup
      },
      set(val) {
        this.$emit('update:querySearchPopup', val)
      }
    }
  },
  methods: {
    moment,

    // 查询列表数据（校验成功后）
    searchData() {
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    },

    // 重置数据
    resetData() {
      /*
      * 重置数据，从父组件找到 “customQueryPrams对象” 的原始结构
      * 因为 “customQueryPrams对象”是计算属性的return数据结构
      * 不能使 customQueryPrams对象地址值发生改变，因而进行循环赋值处理
      * */
      Object.keys(this.customQueryPrams).forEach(key => {
        this.customQueryPrams[key] = this.$parent.$options.data().customQueryPrams[key]
      })
      this.$emit('searchData', this.customQueryPrams)
      this.isShowPopup = false // 关闭筛选弹层
    }

  }
}
</script>

<style lang="scss" scoped>
.query-search-popup {
  display: flex;
  flex-direction: column;
  height: 100%;

  .title {
    width: 100%;
    box-sizing: border-box;
    padding: 130px 0 100px 0;
    display: flex;
    align-items: center;
    justify-content: center;
    font-size: 80px;
  }

  .van-form {
    flex: 1;
    position: relative;

    .search-btn {
      display: flex;
      position: absolute;
      bottom: 5%;
      width: 80%;
      transform: translateX(-50%);
      left: 50%;

      .van-button {

        &.btn-left {
          border-radius: 999px 0 0 999px;
        }

        &.btn-right {
          border-radius: 0 999px 999px 0;
        }

        .van-button__text {
          font-size: 65px;
        }
      }


    }
  }

}
</style>

